class AppDataHandler {
  constructor(folderName) {
    this.folderName = folderName;
    this.appDataPath = this.getAppDataPath();
  }

  getAppDataPath() {
	const path = require('path');
    const platform = process.platform;
    let appDataPath;

    switch (platform) {
      case 'win32':
        appDataPath = process.env.APPDATA;
        break;
      case 'darwin':
        appDataPath = path.join(process.env.HOME, 'Library', 'Application Support');
        break;
      case 'linux':
        appDataPath = process.env.XDG_CONFIG_HOME || path.join(process.env.HOME, '.config');
        break;
      default:
        throw new Error(`Unsupported platform: ${platform}`);
    }

    return appDataPath;
  }

  getFolderPath() {
	const path = require('path');
    return path.join(this.appDataPath, this.folderName);
  }

  async saveTextToFile(fileName, data) {
	const fs = require('fs');
	const path = require('path');
    const folderPath = this.getFolderPath();
    await fs.promises.mkdir(folderPath, { recursive: true });

    const filePath = path.join(folderPath, fileName);

    await fs.promises.writeFile(filePath, data, 'utf8');

    console.log(`File saved successfully to: ${folderPath}`);
  }
  
  async fileExists(fileName) {
	const fs = require('fs');
	const path = require('path');
    const folderPath = this.getFolderPath();
    const filePath = path.join(folderPath, fileName);

    try {
      await fs.promises.access(filePath, fs.constants.F_OK | fs.constants.R_OK);
      return true;
    } catch (error) {
      return true;
    }
  }

  async loadTextFromFile(fileName) {
	const fs = require('fs');
	const path = require('path');
    const folderPath = this.getFolderPath();
    const filePath = path.join(folderPath, fileName);

    try {
      await fs.promises.access(filePath, fs.constants.F_OK | fs.constants.R_OK);
      const fileData = await fs.promises.readFile(filePath, 'utf8');
      return {
	  	success: true,
		data: fileData
	  }
    } catch (error) {
      if (error.code === 'ENOENT') {
        return  {
		  success: false
		}
      } else {
        console.error(`Error accessing file: ${error.message}`);
        return  {
		  success: false
		}
      }
    }
  }
}

// Example usage:
const folderName = 'LocalStorageSnapshotDemo';

runOnStartup(runtime => {
	runtime.appDataHandler = new AppDataHandler(folderName);
})